from ..src.repos import APIRepo
from ..src.usecases.datasets import DownloadDataset
from .retrieve import retrieve_dataset
from ..auth import with_auth


@with_auth
def download_dataset(name, path=None, logger=None, user=None):
    dataset = retrieve_dataset(name)
    dataset_id = dataset["id"]
    checksum = dataset["checksum"]
    api_repo = APIRepo()
    download = DownloadDataset(api_repo, logger)
    inputs = download.Inputs(
        dataset=dataset_id, checksum=checksum, path=path, user=user
    )
    outputs = download(inputs)
    return outputs.dst_path



from .ingest import ingest_dataset, ingest_large_dataset, ingest_q0, ingest_q1
from .download import download_dataset
from .retrieve import retrieve_datasets, retrieve_dataset, list_datasets
from .update import update_dataset



from ..src.repos import APIRepo
from ..src.usecases.datasets import IngestDataset, IngestLargeDataset
from ..auth import with_auth


@with_auth
def ingest_dataset(name, description, path, logger=None, user=None):
    api_repo = APIRepo()
    ingest = IngestDataset(
        api_repo,
    )
    inputs = ingest.Inputs(name=name, description=description, path=path, user=user)
    outputs = ingest(inputs)
    return outputs.dataset


@with_auth
def ingest_large_dataset(name, path, logger=None, user=None):
    api_repo = APIRepo()
    ingest = IngestLargeDataset(api_repo, logger)
    inputs = ingest.Inputs(name=name, path=path, user=user)
    outputs = ingest(inputs)
    return outputs.dataset


def ingest_q0(dataset, path):
    return ingest_large_dataset(dataset, path)


def ingest_q1(dataset, stac_catalog):
    print("holas")
    return



from ..src.repos import APIRepo
from ..src.usecases.datasets import UpdateDataset
from ..auth import with_auth


@with_auth
def update_dataset(name, path, logger=None, user=None):
    api_repo = APIRepo()
    ingest = UpdateDataset(api_repo, logger)
    inputs = ingest.Inputs(name=name, path=path, user=user)
    outputs = ingest(inputs)
    return outputs.dataset
